@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 import unittest
 
 import rules_light
@@ -5,7 +7,7 @@ import rules_light
 
 class AutodiscoverTestCase(unittest.TestCase):
     def test_autodiscover(self):
-        self.assertEqual(rules_light.registry.keys(), [])
+        self.assertEqual(list(rules_light.registry.keys()), [])
         rules_light.autodiscover()
         self.assertTrue('rules_light.rule.read' in rules_light.registry.keys())
         self.assertFalse('Foo bar' in rules_light.registry.keys())
